=== modified file 'bzrlib/tests/test_transform.py'
--- bzrlib/tests/test_transform.py	2007-02-08 22:18:50 +0000
+++ bzrlib/tests/test_transform.py	2007-02-09 15:28:12 +0000
@@ -691,6 +691,31 @@
         finally:
             transform.finalize()
 
+    def test_iter_changes_modified_bleed(self):
+        """Modified flag should not bleed from one change to another"""
+        # unfortunately, we have no guarantee that file1 (which is modified)
+        # will be applied before file2.  And if it's applied after file2, it
+        # obviously can't bleed into file2's change output.  But for now, it
+        # works.
+        transform, root = self.get_transform()
+        transform.new_file('file1', root, 'blah', 'id-1')
+        transform.new_file('file2', root, 'blah', 'id-2')
+        transform.apply()
+        transform, root = self.get_transform()
+        try:
+            transform.delete_contents(transform.trans_id_file_id('id-1'))
+            transform.set_executability(True,
+            transform.trans_id_file_id('id-2'))
+            self.assertEqual([('id-1', u'file1', True, (True, True),
+                ('TREE_ROOT', 'TREE_ROOT'), ('file1', u'file1'),
+                ('file', None), (False, False)),
+                ('id-2', u'file2', False, (True, True),
+                ('TREE_ROOT', 'TREE_ROOT'), ('file2', u'file2'),
+                ('file', 'file'), (False, True))],
+                list(transform._iter_changes()))
+        finally:
+            transform.finalize()
+
     def test_iter_changes_pointless(self):
         """Ensure that no-ops are not treated as modifications"""
         transform, root = self.get_transform()

=== modified file 'bzrlib/transform.py'
--- bzrlib/transform.py	2007-02-09 15:05:23 +0000
+++ bzrlib/transform.py	2007-02-09 15:28:12 +0000
@@ -923,7 +923,6 @@
         trans_ids.update(self._new_parent.keys())
         from_trans_ids = {}
         to_trans_ids = {}
-        modified = False
         # Build up two dicts: trans_ids associated with file ids in the
         # FROM state, vs the TO state.
         for trans_id in trans_ids:
@@ -938,6 +937,7 @@
 
         # Now iterate through all active file_ids
         for file_id in set(from_trans_ids.keys() + to_trans_ids.keys()):
+            modified = False
             from_trans_id = from_trans_ids.get(file_id)
             # find file ids, and determine versioning state
             if from_trans_id is None:

